==> PrivateNUnit0.0.1.zip: PrivateNUnit/PrivateNUnit/PrivateNUnit.cs <==
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace PrivateNUnit
{
	/// <summary>
	/// PrivateNUnit ̊Tv̐łB
	/// </summary>
	public class PrivateNUnit : System.Windows.Forms.Form
	{
		private System.Windows.Forms.TextBox txtAssemblyPath;
		private System.Windows.Forms.Button btnSelectAssembly;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.TextBox txtClassForGenerate;
		private System.Windows.Forms.OpenFileDialog openFileDialog;
		private System.Windows.Forms.Button btnGenerate;
		/// <summary>
		/// KvȃfUCiϐłB
		/// </summary>
		private System.ComponentModel.Container components = null;

		public PrivateNUnit()
		{
			//
			// Windows tH[ fUCi T|[gɕKvłB
			//
			InitializeComponent();

			//
			// TODO: InitializeComponent ĂяǒɁARXgN^ R[hǉĂB
			//
		}

		/// <summary>
		/// gpĂ郊\[XɌ㏈s܂B
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows tH[ fUCiŐꂽR[h 
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
			this.txtAssemblyPath = new System.Windows.Forms.TextBox();
			this.txtClassForGenerate = new System.Windows.Forms.TextBox();
			this.btnSelectAssembly = new System.Windows.Forms.Button();
			this.label1 = new System.Windows.Forms.Label();
			this.openFileDialog = new System.Windows.Forms.OpenFileDialog();
			this.btnGenerate = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// txtAssemblyPath
			// 
			this.txtAssemblyPath.Location = new System.Drawing.Point(8, 8);
			this.txtAssemblyPath.Name = "txtAssemblyPath";
			this.txtAssemblyPath.Size = new System.Drawing.Size(392, 19);
			this.txtAssemblyPath.TabIndex = 0;
			this.txtAssemblyPath.Text = "";
			// 
			// txtClassForGenerate
			// 
			this.txtClassForGenerate.Location = new System.Drawing.Point(8, 72);
			this.txtClassForGenerate.Name = "txtClassForGenerate";
			this.txtClassForGenerate.Size = new System.Drawing.Size(392, 19);
			this.txtClassForGenerate.TabIndex = 1;
			this.txtClassForGenerate.Text = "";
			// 
			// btnSelectAssembly
			// 
			this.btnSelectAssembly.Location = new System.Drawing.Point(424, 8);
			this.btnSelectAssembly.Name = "btnSelectAssembly";
			this.btnSelectAssembly.Size = new System.Drawing.Size(128, 23);
			this.btnSelectAssembly.TabIndex = 2;
			this.btnSelectAssembly.Text = "Select Assembly";
			this.btnSelectAssembly.Click += new System.EventHandler(this.btnSelectAssembly_Click);
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 48);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(232, 16);
			this.label1.TabIndex = 3;
			this.label1.Text = "Type Cless Name in FQDN";
			// 
			// btnGenerate
			// 
			this.btnGenerate.Location = new System.Drawing.Point(8, 104);
			this.btnGenerate.Name = "btnGenerate";
			this.btnGenerate.Size = new System.Drawing.Size(136, 23);
			this.btnGenerate.TabIndex = 4;
			this.btnGenerate.Text = "Generate";
			this.btnGenerate.Click += new System.EventHandler(this.btnGenerate_Click);
			// 
			// PrivateNUnit
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
			this.ClientSize = new System.Drawing.Size(576, 273);
			this.Controls.Add(this.btnGenerate);
			this.Controls.Add(this.label1);
			this.Controls.Add(this.btnSelectAssembly);
			this.Controls.Add(this.txtClassForGenerate);
			this.Controls.Add(this.txtAssemblyPath);
			this.Name = "PrivateNUnit";
			this.Text = "PrivateNUnit";
			this.ResumeLayout(false);

		}

		/// <summary>
		/// AvP[ṼC Gg |CgłB
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new PrivateNUnit());
		}
		#endregion

		private void btnSelectAssembly_Click(object sender, System.EventArgs e)
		{
			if(openFileDialog.ShowDialog() == DialogResult.OK)
			{
				txtAssemblyPath.Text = openFileDialog.FileName;
			}
		}

		private void btnGenerate_Click(object sender, System.EventArgs e)
		{
		
		}
	}
}

==> PrivateNUnit0.0.2.zip: PrivateNUnit/PrivateNUnit/PrivateNUnit.cs <==
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Reflection;
using System.Windows.Forms;
using PrivateNUnitCore;

namespace PrivateNUnit
{
	/// <summary>
	/// PrivateNUnit ̊Tv̐łB
	/// </summary>
	public class PrivateNUnit : System.Windows.Forms.Form
	{
		private System.Windows.Forms.TextBox txtAssemblyPath;
		private System.Windows.Forms.Button btnSelectAssembly;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.TextBox txtClassForGenerate;
		private System.Windows.Forms.OpenFileDialog openFileDialog;
		private System.Windows.Forms.Button btnGenerate;
		private System.Windows.Forms.TextBox txtResult;
		private System.Windows.Forms.Button btnCopyClipboard;
		/// <summary>
		/// KvȃfUCiϐłB
		/// </summary>
		private System.ComponentModel.Container components = null;

		public PrivateNUnit()
		{
			//
			// Windows tH[ fUCi T|[gɕKvłB
			//
			InitializeComponent();

			//
			// TODO: InitializeComponent ĂяǒɁARXgN^ R[hǉĂB
			//
		}

		/// <summary>
		/// gpĂ郊\[XɌ㏈s܂B
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows tH[ fUCiŐꂽR[h 
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
			this.txtAssemblyPath = new System.Windows.Forms.TextBox();
			this.txtClassForGenerate = new System.Windows.Forms.TextBox();
			this.btnSelectAssembly = new System.Windows.Forms.Button();
			this.label1 = new System.Windows.Forms.Label();
			this.openFileDialog = new System.Windows.Forms.OpenFileDialog();
			this.btnGenerate = new System.Windows.Forms.Button();
			this.txtResult = new System.Windows.Forms.TextBox();
			this.btnCopyClipboard = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// txtAssemblyPath
			// 
			this.txtAssemblyPath.Location = new System.Drawing.Point(8, 8);
			this.txtAssemblyPath.Name = "txtAssemblyPath";
			this.txtAssemblyPath.Size = new System.Drawing.Size(392, 19);
			this.txtAssemblyPath.TabIndex = 0;
			this.txtAssemblyPath.Text = "C:\\Documents and Settings\\Administrator\\My Documents\\Visual Studio Projects\\Priva" +
				"teNUnit\\PrivateNUnitCore\\bin\\Debug\\PrivateNUnitCore.dll";
			// 
			// txtClassForGenerate
			// 
			this.txtClassForGenerate.Location = new System.Drawing.Point(8, 72);
			this.txtClassForGenerate.Name = "txtClassForGenerate";
			this.txtClassForGenerate.Size = new System.Drawing.Size(392, 19);
			this.txtClassForGenerate.TabIndex = 1;
			this.txtClassForGenerate.Text = "PrivateNUnitCore.TestCaseGenerator";
			// 
			// btnSelectAssembly
			// 
			this.btnSelectAssembly.Location = new System.Drawing.Point(424, 8);
			this.btnSelectAssembly.Name = "btnSelectAssembly";
			this.btnSelectAssembly.Size = new System.Drawing.Size(128, 23);
			this.btnSelectAssembly.TabIndex = 2;
			this.btnSelectAssembly.Text = "Select Assembly";
			this.btnSelectAssembly.Click += new System.EventHandler(this.btnSelectAssembly_Click);
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 48);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(232, 16);
			this.label1.TabIndex = 3;
			this.label1.Text = "Type Cless Name in FQDN";
			// 
			// btnGenerate
			// 
			this.btnGenerate.Location = new System.Drawing.Point(8, 104);
			this.btnGenerate.Name = "btnGenerate";
			this.btnGenerate.Size = new System.Drawing.Size(136, 23);
			this.btnGenerate.TabIndex = 4;
			this.btnGenerate.Text = "Generate";
			this.btnGenerate.Click += new System.EventHandler(this.btnGenerate_Click);
			// 
			// txtResult
			// 
			this.txtResult.Location = new System.Drawing.Point(8, 144);
			this.txtResult.Multiline = true;
			this.txtResult.Name = "txtResult";
			this.txtResult.ScrollBars = System.Windows.Forms.ScrollBars.Both;
			this.txtResult.Size = new System.Drawing.Size(608, 288);
			this.txtResult.TabIndex = 5;
			this.txtResult.Text = "";
			// 
			// btnCopyClipboard
			// 
			this.btnCopyClipboard.Location = new System.Drawing.Point(168, 104);
			this.btnCopyClipboard.Name = "btnCopyClipboard";
			this.btnCopyClipboard.Size = new System.Drawing.Size(120, 23);
			this.btnCopyClipboard.TabIndex = 6;
			this.btnCopyClipboard.Text = "Copy to Clipboard";
			this.btnCopyClipboard.Click += new System.EventHandler(this.btnCopyClipboard_Click);
			// 
			// PrivateNUnit
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
			this.ClientSize = new System.Drawing.Size(640, 453);
			this.Controls.Add(this.btnCopyClipboard);
			this.Controls.Add(this.txtResult);
			this.Controls.Add(this.btnGenerate);
			this.Controls.Add(this.label1);
			this.Controls.Add(this.btnSelectAssembly);
			this.Controls.Add(this.txtClassForGenerate);
			this.Controls.Add(this.txtAssemblyPath);
			this.Name = "PrivateNUnit";
			this.Text = "PrivateNUnit";
			this.ResumeLayout(false);

		}

		/// <summary>
		/// AvP[ṼC Gg |CgłB
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new PrivateNUnit());
		}
		#endregion

		private void btnSelectAssembly_Click(object sender, System.EventArgs e)
		{
			if(openFileDialog.ShowDialog() == DialogResult.OK)
			{
				txtAssemblyPath.Text = openFileDialog.FileName;
			}
		}

		private void btnGenerate_Click(object sender, System.EventArgs e)
		{
			ClassAnalyzer analyzer = new ClassAnalyzer(txtAssemblyPath.Text,txtClassForGenerate.Text);
			TestCaseGenerator generator = new TestCaseGenerator(txtClassForGenerate.Text,analyzer.Analyze());
			string testCase = generator.Generate();
			txtResult.Text = testCase;
		}

		private void btnCopyClipboard_Click(object sender, System.EventArgs e)
		{
			Clipboard.SetDataObject(txtResult.Text,true);
		}
	}
}
